==> quarkus-smallrye-health-deployment-2.0.2.Final-sources.jar: io/quarkus/smallrye/health/deployment/SmallRyeHealthConfig$$accessor.java <==
package io.quarkus.smallrye.health.deployment;
public final class SmallRyeHealthConfig$$accessor {
    private SmallRyeHealthConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_rootPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).rootPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_rootPath(Object __instance, Object rootPath) {
        ((SmallRyeHealthConfig)__instance).rootPath = (String)rootPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_livenessPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).livenessPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_livenessPath(Object __instance, Object livenessPath) {
        ((SmallRyeHealthConfig)__instance).livenessPath = (String)livenessPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_readinessPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).readinessPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_readinessPath(Object __instance, Object readinessPath) {
        ((SmallRyeHealthConfig)__instance).readinessPath = (String)readinessPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_groupPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).groupPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_groupPath(Object __instance, Object groupPath) {
        ((SmallRyeHealthConfig)__instance).groupPath = (String)groupPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_wellnessPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).wellnessPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_wellnessPath(Object __instance, Object wellnessPath) {
        ((SmallRyeHealthConfig)__instance).wellnessPath = (String)wellnessPath;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_contextPropagation(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).contextPropagation;
    }
    @SuppressWarnings("unchecked")
    public static void set_contextPropagation(Object __instance, boolean contextPropagation) {
        ((SmallRyeHealthConfig)__instance).contextPropagation = contextPropagation;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ui(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).ui;
    }
    @SuppressWarnings("unchecked")
    public static void set_ui(Object __instance, Object ui) {
        ((SmallRyeHealthConfig)__instance).ui = (SmallRyeHealthUIConfig)ui;
    }
}

==> quarkus-smallrye-health-deployment-2.10.0.Final-sources.jar: io/quarkus/smallrye/health/deployment/SmallRyeHealthConfig$$accessor.java <==
package io.quarkus.smallrye.health.deployment;
public final class SmallRyeHealthConfig$$accessor {
    private SmallRyeHealthConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_rootPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).rootPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_rootPath(Object __instance, Object rootPath) {
        ((SmallRyeHealthConfig)__instance).rootPath = (String)rootPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_livenessPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).livenessPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_livenessPath(Object __instance, Object livenessPath) {
        ((SmallRyeHealthConfig)__instance).livenessPath = (String)livenessPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_readinessPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).readinessPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_readinessPath(Object __instance, Object readinessPath) {
        ((SmallRyeHealthConfig)__instance).readinessPath = (String)readinessPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_groupPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).groupPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_groupPath(Object __instance, Object groupPath) {
        ((SmallRyeHealthConfig)__instance).groupPath = (String)groupPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_wellnessPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).wellnessPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_wellnessPath(Object __instance, Object wellnessPath) {
        ((SmallRyeHealthConfig)__instance).wellnessPath = (String)wellnessPath;
    }
    @SuppressWarnings("unchecked")
    public static Object get_startupPath(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).startupPath;
    }
    @SuppressWarnings("unchecked")
    public static void set_startupPath(Object __instance, Object startupPath) {
        ((SmallRyeHealthConfig)__instance).startupPath = (String)startupPath;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_contextPropagation(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).contextPropagation;
    }
    @SuppressWarnings("unchecked")
    public static void set_contextPropagation(Object __instance, boolean contextPropagation) {
        ((SmallRyeHealthConfig)__instance).contextPropagation = contextPropagation;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ui(Object __instance) {
        return ((SmallRyeHealthConfig)__instance).ui;
    }
    @SuppressWarnings("unchecked")
    public static void set_ui(Object __instance, Object ui) {
        ((SmallRyeHealthConfig)__instance).ui = (SmallRyeHealthUIConfig)ui;
    }
}
